@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -36,7 +36,8 @@ class AsrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CloseAsyncRecognitionTask", params)
+            headers = request.headers
+            body = self.call("CloseAsyncRecognitionTask", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CloseAsyncRecognitionTaskResponse()
@@ -69,7 +70,8 @@ class AsrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateAsrVocab", params)
+            headers = request.headers
+            body = self.call("CreateAsrVocab", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateAsrVocabResponse()
@@ -102,7 +104,8 @@ class AsrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateAsyncRecognitionTask", params)
+            headers = request.headers
+            body = self.call("CreateAsyncRecognitionTask", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateAsyncRecognitionTaskResponse()
@@ -130,7 +133,8 @@ class AsrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateCustomization", params)
+            headers = request.headers
+            body = self.call("CreateCustomization", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateCustomizationResponse()
@@ -150,17 +154,17 @@ class AsrClient(AbstractClient):
 
     def CreateRecTask(self, request):
         """本接口服务对时长5小时以内的录音文件进行识别，异步返回识别全部结果。
-        <br>• 支持中文普通话、英语、粤语、日语、泰语
-        <br>• 支持通用、音视频领域
-        <br>• 支持wav、mp3、m4a、flv、mp4、wma、3gp、amr、aac、ogg-opus、flac格式
-        <br>• 支持语音 URL 和本地语音文件两种请求方式
-        <br>• 语音 URL 的音频时长不能长于5小时，文件大小不超过512MB
-        <br>• 本地语音文件不能大于5MB
-        <br>• 提交录音文件识别请求后，在5小时内完成识别（半小时内发送超过1000小时录音或者2万条识别任务的除外），识别结果在服务端可保存7天
-        <br>• 支持回调或轮询的方式获取结果，结果获取请参考[ 录音文件识别结果查询](https://cloud.tencent.com/document/product/1093/37822)。
-        <br>•   请求方法为 HTTP POST , Content-Type为"application/json; charset=utf-8"
-        <br>•   签名方法参考 [公共参数](https://cloud.tencent.com/document/api/1093/35640) 中签名方法v3。
-        <br>• 默认接口请求频率限制：20次/秒，如您有提高请求频率限制的需求，请提[工单](https://console.cloud.tencent.com/workorder/category)进行咨询。
+        • 支持中文普通话、英语、粤语、日语、上海话、四川话、武汉话、贵阳话、昆明话、西安话、郑州话、太原话、兰州话、银川话、西宁话、南京话、合肥话、南昌话、长沙话、苏州话、杭州话、济南话、天津话、石家庄话、黑龙江话、吉林话、辽宁话。
+        • 支持通用、音视频领域
+        • 支持wav、mp3、m4a、flv、mp4、wma、3gp、amr、aac、ogg-opus、flac格式
+        • 支持语音 URL 和本地语音文件两种请求方式
+        • 语音 URL 的音频时长不能长于5小时，文件大小不超过512MB
+        • 本地语音文件不能大于5MB
+        • 提交录音文件识别请求后，在3小时内完成识别（大多数情况下1小时音频约3分钟以内完成识别，半小时内发送超过1000小时录音或者2万条识别任务的除外），识别结果在服务端可保存7天
+        • 支持回调或轮询的方式获取结果，结果获取请参考[ 录音文件识别结果查询](https://cloud.tencent.com/document/product/1093/37822)。
+        •   请求方法为 HTTP POST , Content-Type为"application/json; charset=utf-8"
+        •   签名方法参考 [公共参数](https://cloud.tencent.com/document/api/1093/35640) 中签名方法v3。
+        • 默认接口请求频率限制：20次/秒，如您有提高请求频率限制的需求，请提[工单](https://console.cloud.tencent.com/workorder/category)进行咨询。
 
         :param request: Request instance for CreateRecTask.
         :type request: :class:`tencentcloud.asr.v20190614.models.CreateRecTaskRequest`
@@ -169,7 +173,8 @@ class AsrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateRecTask", params)
+            headers = request.headers
+            body = self.call("CreateRecTask", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateRecTaskResponse()
@@ -197,7 +202,8 @@ class AsrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteAsrVocab", params)
+            headers = request.headers
+            body = self.call("DeleteAsrVocab", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteAsrVocabResponse()
@@ -225,7 +231,8 @@ class AsrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteCustomization", params)
+            headers = request.headers
+            body = self.call("DeleteCustomization", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteCustomizationResponse()
@@ -254,7 +261,8 @@ class AsrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAsyncRecognitionTasks", params)
+            headers = request.headers
+            body = self.call("DescribeAsyncRecognitionTasks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAsyncRecognitionTasksResponse()
@@ -287,7 +295,8 @@ class AsrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTaskStatus", params)
+            headers = request.headers
+            body = self.call("DescribeTaskStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTaskStatusResponse()
@@ -315,7 +324,8 @@ class AsrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DownloadAsrVocab", params)
+            headers = request.headers
+            body = self.call("DownloadAsrVocab", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DownloadAsrVocabResponse()
@@ -343,7 +353,8 @@ class AsrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DownloadCustomization", params)
+            headers = request.headers
+            body = self.call("DownloadCustomization", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DownloadCustomizationResponse()
@@ -371,7 +382,8 @@ class AsrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetAsrVocab", params)
+            headers = request.headers
+            body = self.call("GetAsrVocab", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetAsrVocabResponse()
@@ -399,7 +411,8 @@ class AsrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetAsrVocabList", params)
+            headers = request.headers
+            body = self.call("GetAsrVocabList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetAsrVocabListResponse()
@@ -427,7 +440,8 @@ class AsrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetCustomizationList", params)
+            headers = request.headers
+            body = self.call("GetCustomizationList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetCustomizationListResponse()
@@ -455,7 +469,8 @@ class AsrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyCustomization", params)
+            headers = request.headers
+            body = self.call("ModifyCustomization", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyCustomizationResponse()
@@ -483,7 +498,8 @@ class AsrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyCustomizationState", params)
+            headers = request.headers
+            body = self.call("ModifyCustomizationState", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyCustomizationStateResponse()
@@ -502,14 +518,7 @@ class AsrClient(AbstractClient):
 
 
     def SentenceRecognition(self, request):
-        """本接口用于对60秒之内的短音频文件进行识别。
-        <br>•   支持中文普通话、英语、粤语、日语、上海话方言。
-        <br>•   支持本地语音文件上传和语音URL上传两种请求方式，音频时长不能超过60s。
-        <br>•   音频格式支持wav、mp3；采样率支持8000Hz或者16000Hz；采样精度支持16bits；声道支持单声道。
-        <br>•   当音频文件通过请求中body内容上传时，请求大小不能超过3MB。
-        <br>•   请求方法为 HTTP POST , Content-Type为"application/json; charset=utf-8"
-        <br>•   签名方法参考 [公共参数](https://cloud.tencent.com/document/api/1093/35640) 中签名方法v3。
-        <br>•   默认接口请求频率限制：25次/秒，如您有提高请求频率限制的需求，请提[工单](https://console.cloud.tencent.com/workorder/category)进行咨询。
+        """本接口用于对60秒之内的短音频文件进行识别。<br>•   支持中文普通话、英语、粤语、日语、上海话、四川话、武汉话、贵阳话、昆明话、西安话、郑州话、太原话、兰州话、银川话、西宁话、南京话、合肥话、南昌话、长沙话、苏州话、杭州话、济南话、天津话、石家庄话、黑龙江话、吉林话、辽宁话。<br>•   支持本地语音文件上传和语音URL上传两种请求方式，音频时长不能超过60s，音频文件大小不能超过3MB。<br>•   音频格式支持wav、pcm、ogg-opus、speex、silk、mp3、m4a、aac；采样率建议8000Hz或者16000Hz；采样精度建议16bits；声道支持单声道。<br>•   请求方法为 HTTP POST , Content-Type为"application/json; charset=utf-8"<br>•   签名方法参考 [公共参数](https://cloud.tencent.com/document/api/1093/35640) 中签名方法v3。<br>•   默认接口请求频率限制：25次/秒，如您有提高请求频率限制的需求，请提[工单](https://console.cloud.tencent.com/workorder/category)进行咨询。
 
         :param request: Request instance for SentenceRecognition.
         :type request: :class:`tencentcloud.asr.v20190614.models.SentenceRecognitionRequest`
@@ -518,7 +527,8 @@ class AsrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SentenceRecognition", params)
+            headers = request.headers
+            body = self.call("SentenceRecognition", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SentenceRecognitionResponse()
@@ -546,7 +556,8 @@ class AsrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SetVocabState", params)
+            headers = request.headers
+            body = self.call("SetVocabState", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SetVocabStateResponse()
@@ -574,7 +585,8 @@ class AsrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateAsrVocab", params)
+            headers = request.headers
+            body = self.call("UpdateAsrVocab", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateAsrVocabResponse()
